/*
 * Copyright (C) 2017, 1C
 */

package com.e1c.test.sqlite;

import java.io.File;

import com.e1c.test.kv.IKVDatabase;
import com.e1c.test.kv.IKVReadTransaction;
import com.e1c.test.kv.IKVSequence;
import com.e1c.test.kv.IKVWriteTransaction;
import com.e1c.test.utils.ByteString;


public class SQLiteKVDatabase implements IKVDatabase
{
    private static final String createTableStatement =
            "CREATE TABLE IF NOT EXISTS key_value (k BLOB PRIMARY KEY, v BLOB);";

    private final String databaseName;
    private final int queryPageSize;


    public static SQLiteKVDatabase openOrCreate(String databaseName, int queryPageSize)
    {
        return new SQLiteKVDatabase(databaseName, queryPageSize);
    }

    private SQLiteKVDatabase(String databaseName, int queryPageSize)
    {
        this.databaseName = databaseName;
        this.queryPageSize = queryPageSize;
    }

    @Override
    public IKVReadTransaction beginReadTransaction()
    {
        return SQLiteKeyValueStore.openForRead(databaseName, queryPageSize);
    }

    @Override
    public IKVWriteTransaction beginWriteTransaction()
    {
        return SQLiteKeyValueStore.openForWrite(databaseName, queryPageSize);
    }

    @Override
    public void put(ByteString key, ByteString value)
    {
         try (SQLiteKeyValueStore store = SQLiteKeyValueStore.openForWrite(databaseName, queryPageSize))
         {
             store.put(key, value);
             store.commit();
         }
    }

    @Override
    public void delete(ByteString key)
    {
        try (SQLiteKeyValueStore store = SQLiteKeyValueStore.openForWrite(databaseName, queryPageSize))
        {
            store.delete(key);
            store.commit();
        }
    }

    @Override
    public ByteString get(ByteString key)
    {
        try (SQLiteKeyValueStore store = SQLiteKeyValueStore.openForRead(databaseName, queryPageSize))
        {
            return store.get(key);
        }
    }

    @Override
    public IKVSequence sequence()
    {
        SQLiteKeyValueStore store = null;
        try
        {
            store = SQLiteKeyValueStore.openForRead(databaseName, queryPageSize);
            return new SQLiteSequence(store, true);
        }
        catch (Throwable e)
        {
            if (store != null)
                store.close();

            throw e;
        }
    }

    @Override
    public void close()
    {
    }

    public static void destroy(String dbName)
    {
        String databasePath = "";
        File databaseFile = new File(databasePath);
    }
}
