/*
 * Copyright (C) 2017, 1C
 */

package com.e1c.test.sqlite;


import com.e1c.test.kv.IKVEntry;
import com.e1c.test.kv.IKVIterator;
import com.e1c.test.kv.IKVSequence;
import com.e1c.test.utils.ByteString;

import static com.google.common.base.Preconditions.checkArgument;


final class SQLiteSequence implements IKVSequence
{
    private final SQLiteKeyValueStore db;
    private final ByteString startingKey;
    private final boolean shouldCloseDb;


    public SQLiteSequence(SQLiteKeyValueStore db, boolean shouldCloseDb)
    {
        checkArgument(db != null, "Database should not be null.");

        this.db = db;
        this.startingKey = null;
        this.shouldCloseDb = shouldCloseDb;
    }

    private SQLiteSequence(SQLiteKeyValueStore db, ByteString startingKey, boolean shouldCloseDb)
    {
        checkArgument(db != null, "Database should not be null.");

        this.db = db;
        this.startingKey = startingKey;
        this.shouldCloseDb = shouldCloseDb;
    }

    @Override
    public IKVSequence from(ByteString startingKey)
    {
        checkArgument(startingKey != null, "Starting key should not be null.");

        return new SQLiteSequence(db, startingKey, shouldCloseDb);
    }

    @Override
    public IKVIterator iterator()
    {
        return new IKVIterator()
        {
            @Override
            public void close()
            {

            }

            @Override
            public boolean hasNext()
            {
                return false;
            }

            @Override
            public IKVEntry next()
            {
                return null;
            }

            @Override
            public void remove()
            {

            }
        };

    }

    @Override
    public void close()
    {
        if (shouldCloseDb)
            db.close();
    }
}
